        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>35</strong> miembros: 13 <strong>control</strong><br>0,4,8,10,19,20,27,28,31,35,41,45,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 12 <br>1,2,6,13,21,23,24,26,33,34,42,50';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 11 <br>3,5,15,16,17,18,30,32,36,38,46';}
       if(rr==5 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>9</strong> miembros: 9 <br>7,9,14,22,40,43,44,47,48';}
       if(rr==5 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>11</strong> miembros: 6 <br>11,12,25,29,37,39';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>35</strong> miembros: 13 <strong>control</strong><br>0,4,8,10,19,20,27,28,31,35,41,45,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 12 <br>1,2,6,13,21,23,24,26,33,34,42,50';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 11 <br>3,5,15,16,17,18,30,32,36,38,46';}
       if(rr==40 && cc==4){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>9</strong> miembros: 9 <br>7,9,14,22,40,43,44,47,48';}
       if(rr==40 && cc==5){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>11</strong> miembros: 6 <br>11,12,25,29,37,39';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>35</strong> miembros: 13 <strong>control</strong><br>0,4,8,10,19,20,27,28,31,35,41,45,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 12 <br>1,2,6,13,21,23,24,26,33,34,42,50';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 11 <br>3,5,15,16,17,18,30,32,36,38,46';}
       if(rr==41 && cc==4){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>9</strong> miembros: 9 <br>7,9,14,22,40,43,44,47,48';}
       if(rr==41 && cc==5){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>11</strong> miembros: 6 <br>11,12,25,29,37,39';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>35</strong> miembros: 13 <strong>control</strong><br>0,4,8,10,19,20,27,28,31,35,41,45,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 12 <br>1,2,6,13,21,23,24,26,33,34,42,50';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 11 <br>3,5,15,16,17,18,30,32,36,38,46';}
       if(rr==42 && cc==4){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>9</strong> miembros: 9 <br>7,9,14,22,40,43,44,47,48';}
       if(rr==42 && cc==5){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>11</strong> miembros: 6 <br>11,12,25,29,37,39';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>35</strong> miembros: 13 <strong>control</strong><br>0,4,8,10,19,20,27,28,31,35,41,45,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>34</strong> miembros: 12 <br>1,2,6,13,21,23,24,26,33,34,42,50';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 11 <br>3,5,15,16,17,18,30,32,36,38,46';}
       if(rr==43 && cc==4){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>9</strong> miembros: 9 <br>7,9,14,22,40,43,44,47,48';}
       if(rr==43 && cc==5){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260817 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>11</strong> miembros: 6 <br>11,12,25,29,37,39';}
}
